==> webgui_7.9.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Account_Profile.pm <==
package WebGUI::i18n::German::Account_Profile;
use utf8;
our $I18N = {
  'back label' => {
    'lastUpdated' => '1233940902',
    'message' => 'Zurück zur Seite'
  },
  'back to profile label' => {
    'lastUpdated' => '1233940912',
    'message' => 'Zurück zum Profil'
  },
  'edit my profile' => {
    'lastUpdated' => '1228751219',
    'message' => 'Mein Profil bearbeiten'
  },
  'error label' => {
    'lastUpdated' => '1228751210',
    'message' => 'Fehler'
  },
  'friends only' => {
    'lastUpdated' => '1228751185',
    'message' => 'Ihr Profil ist von Freunden einsehbar.'
  },
  'friends only label' => {
    'lastUpdated' => '1228751203',
    'message' => 'Nur Freunde'
  },
  'member since' => {
    'lastUpdated' => '1233944789',
    'message' => 'Registriert seit dem'
  },
  'private label' => {
    'lastUpdated' => '1233940936',
    'message' => 'Nicht öffentlich'
  },
  'private profile' => {
    'lastUpdated' => '1228751154',
    'message' => 'Ihr Profil ist nicht öffentlich'
  },
  'profile as others label' => {
    'lastUpdated' => '1236436695',
    'message' => 'Profil anzeigen wie von anderen gesehen'
  },
  'profile edit layout template hoverHelp' => {
    'lastUpdated' => '1228751783',
    'message' => 'Wählen Sie ein Layout aus der Liste, zur Anzeige der verschiednenen Account-Plugins, die vom aktuellen Benutzer betrachtet werden können, und des Inhalts des aktuell ausgew&auml;hlten.'
  },
  'profile edit layout template label' => {
    'lastUpdated' => '1233942508',
    'message' => 'Layout'
  },
  'profile edit template hoverHelp' => {
    'lastUpdated' => '1228751326',
    'message' => 'Wählen Sie die Hauptvorlage, um ein Profil zu bearbeiten'
  },
  'profile edit template label' => {
    'lastUpdated' => '1236454988',
    'message' => 'Vorlage Bearbeitung'
  },
  'profile error template hoverHelp' => {
    'lastUpdated' => '1228751380',
    'message' => 'Wählen Sie ein Vorlage, mit der Fehler im Profil dem Benutzer angezeigt werden.'
  },
  'profile error template label' => {
    'lastUpdated' => '1233943619',
    'message' => 'Vorlage Fehlermeldungen'
  },
  'profile layout template hoverHelp' => {
    'lastUpdated' => '1229284173',
    'message' => 'Wählen Sie ein Layout zur Anzeige der verschiedenen Konto-Plugins, die vom aktuellen Benutzer bearbeitet werden können sowie zur Anzeige des Inhalts des aktuell ausgewählten Plugins.'
  },
  'profile layout template label' => {
    'lastUpdated' => '1233942327',
    'message' => 'Layout'
  },
  'profile not public error' => {
    'lastUpdated' => '1228751542',
    'message' => 'Dieses Benutzerprofil ist nicht öffentlich einsehbar.'
  },
  'profile style template hoverHelp' => {
    'lastUpdated' => '1228751519',
    'message' => 'Wählen Sie eine Stil-Vorlage aus der Liste, in die der Nachrichteneingang eingebettet werden soll.'
  },
  'profile style template label' => {
    'lastUpdated' => '1233942361',
    'message' => 'Stilvorlage'
  },
  'profile view template hoverHelp' => {
    'lastUpdated' => '1228751456',
    'message' => 'Wählen Sie die Hauptvorlage, um ein Profil anzuzeigen'
  },
  'profile view template label' => {
    'lastUpdated' => '1236454999',
    'message' => 'Vorlage Darstellung'
  },
  'public label' => {
    'lastUpdated' => '1228751140',
    'message' => 'Öffentlich'
  },
  'public profile' => {
    'lastUpdated' => '1228751129',
    'message' => 'Ihr Profil ist öffentlich'
  },
  'required field' => {
    'lastUpdated' => '1228751117',
    'message' => 'Pflichtfeld'
  },
  'save changes' => {
    'lastUpdated' => '1233942488',
    'message' => 'Änderungen speichern'
  },
  'send friend request label' => {
    'lastUpdated' => '1228751406',
    'message' => 'Freund-Anfrage senden'
  },
  'send private message label' => {
    'lastUpdated' => '1228751085',
    'message' => 'Private Nachricht senden'
  },
  'set by admin' => {
    'lastUpdated' => '1228751068',
    'message' => 'Der Site-Administrator hat dieses Feld als nicht sichtbar markiert.'
  },
  'title' => {
    'lastUpdated' => '1229284060',
    'message' => 'Profil'
  },
  'view my profile' => {
    'lastUpdated' => '1228751035',
    'message' => 'Mein Profil anzeigen'
  },
  'visitor profile restricted' => {
    'lastUpdated' => '1228751427',
    'message' => 'Das Benutzerprofil ist eingeschränkt sichtbar.'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Account_Profile.pm <==
package WebGUI::i18n::German::Account_Profile;
use utf8;
our $I18N = {
  'ascending' => {
    'lastUpdated' => '1308051629',
    'message' => 'Aufsteigend'
  },
  'assetManagerSortColumn label' => {
    'lastUpdated' => '1308051659',
    'message' => 'Asset Manager Sortierspalte'
  },
  'assetManagerSortDirection label' => {
    'lastUpdated' => '1308051672',
    'message' => 'Assetmanager Sortierrichtung'
  },
  'back label' => {
    'lastUpdated' => '1233940902',
    'message' => 'Zurück zur Seite'
  },
  'back to profile label' => {
    'lastUpdated' => '1233940912',
    'message' => 'Zurück zum Profil'
  },
  'descending' => {
    'lastUpdated' => '1308051638',
    'message' => 'Absteigend'
  },
  'edit my profile' => {
    'lastUpdated' => '1228751219',
    'message' => 'Mein Profil bearbeiten'
  },
  'error label' => {
    'lastUpdated' => '1228751210',
    'message' => 'Fehler'
  },
  'friends only' => {
    'lastUpdated' => '1228751185',
    'message' => 'Ihr Profil ist von Freunden einsehbar.'
  },
  'friends only label' => {
    'lastUpdated' => '1228751203',
    'message' => 'Nur Freunde'
  },
  'member since' => {
    'lastUpdated' => '1233944789',
    'message' => 'Registriert seit dem'
  },
  'private label' => {
    'lastUpdated' => '1233940936',
    'message' => 'Nicht öffentlich'
  },
  'private profile' => {
    'lastUpdated' => '1228751154',
    'message' => 'Ihr Profil ist nicht öffentlich'
  },
  'profile as others label' => {
    'lastUpdated' => '1236436695',
    'message' => 'Profil anzeigen wie von anderen gesehen'
  },
  'profile edit layout template hoverHelp' => {
    'lastUpdated' => '1228751783',
    'message' => 'Wählen Sie ein Layout aus der Liste, zur Anzeige der verschiednenen Account-Plugins, die vom aktuellen Benutzer betrachtet werden können, und des Inhalts des aktuell ausgew&auml;hlten.'
  },
  'profile edit layout template label' => {
    'lastUpdated' => '1233942508',
    'message' => 'Layout'
  },
  'profile edit template hoverHelp' => {
    'lastUpdated' => '1228751326',
    'message' => 'Wählen Sie die Hauptvorlage, um ein Profil zu bearbeiten'
  },
  'profile edit template label' => {
    'lastUpdated' => '1236454988',
    'message' => 'Vorlage Bearbeitung'
  },
  'profile error template hoverHelp' => {
    'lastUpdated' => '1228751380',
    'message' => 'Wählen Sie ein Vorlage, mit der Fehler im Profil dem Benutzer angezeigt werden.'
  },
  'profile error template label' => {
    'lastUpdated' => '1233943619',
    'message' => 'Vorlage Fehlermeldungen'
  },
  'profile layout template hoverHelp' => {
    'lastUpdated' => '1229284173',
    'message' => 'Wählen Sie ein Layout zur Anzeige der verschiedenen Konto-Plugins, die vom aktuellen Benutzer bearbeitet werden können sowie zur Anzeige des Inhalts des aktuell ausgewählten Plugins.'
  },
  'profile layout template label' => {
    'lastUpdated' => '1233942327',
    'message' => 'Layout'
  },
  'profile not public error' => {
    'lastUpdated' => '1228751542',
    'message' => 'Dieses Benutzerprofil ist nicht öffentlich einsehbar.'
  },
  'profile style template hoverHelp' => {
    'lastUpdated' => '1228751519',
    'message' => 'Wählen Sie eine Stil-Vorlage aus der Liste, in die der Nachrichteneingang eingebettet werden soll.'
  },
  'profile style template label' => {
    'lastUpdated' => '1233942361',
    'message' => 'Stilvorlage'
  },
  'profile view template hoverHelp' => {
    'lastUpdated' => '1228751456',
    'message' => 'Wählen Sie die Hauptvorlage, um ein Profil anzuzeigen'
  },
  'profile view template label' => {
    'lastUpdated' => '1236454999',
    'message' => 'Vorlage Darstellung'
  },
  'public label' => {
    'lastUpdated' => '1228751140',
    'message' => 'Öffentlich'
  },
  'public profile' => {
    'lastUpdated' => '1228751129',
    'message' => 'Ihr Profil ist öffentlich'
  },
  'required field' => {
    'lastUpdated' => '1228751117',
    'message' => 'Pflichtfeld'
  },
  'save changes' => {
    'lastUpdated' => '1233942488',
    'message' => 'Änderungen speichern'
  },
  'send friend request label' => {
    'lastUpdated' => '1228751406',
    'message' => 'Freund-Anfrage senden'
  },
  'send private message label' => {
    'lastUpdated' => '1228751085',
    'message' => 'Private Nachricht senden'
  },
  'set by admin' => {
    'lastUpdated' => '1228751068',
    'message' => 'Der Site-Administrator hat dieses Feld als nicht sichtbar markiert.'
  },
  'title' => {
    'lastUpdated' => '1229284060',
    'message' => 'Profil'
  },
  'view my profile' => {
    'lastUpdated' => '1228751035',
    'message' => 'Mein Profil anzeigen'
  },
  'visitor profile restricted' => {
    'lastUpdated' => '1228751427',
    'message' => 'Das Benutzerprofil ist eingeschränkt sichtbar.'
  }
}
;

1;
